![Version](https://badge.fury.io/py/EMC-info.svg)  
EarthMC is a large Minecraft server this package lets you get info about things on that server.  
[PyPI](https://pypi.org/project/EMC-info) **|** [Github](https://github.com/TheSuperGamer20578/EMC-info) **|** [Changelog](https://github.com/TheSuperGamer20578/EMC-info/releases) | ~~Documentation~~(Coming soon!)
